#!/bin/bash

function die {
  echo "ERROR: $@" > /dev/stderr
  exit 1
}

awk '' || die "awk is not installed on your system! Please install it and try again."

function strip {
  awk '{print $1}'
}

function check_file {
  [[ -f "$1" ]] || die "File not found: '$1'"
}

check_file 2.1.h
check_file 2.1.h.original

ADDED=$(diff 2.1.h.original 2.1.h | egrep "^>" | wc -l)
REMOVED=$(diff 2.1.h 2.1.h.original | egrep "^>" | wc -l)
(( ADDED <= 1 )) && (( REMOVED == 0 )) \
  || die "You changed 2.1.h too much! ADDED=$ADDED, REMOVED=$REMOVED"

OUT=$(./2.1.test)
EXPECTED="Square
Square: area=90.250000"

if [[ "$OUT" = "$EXPECTED" ]]; then
  echo "SUCCESS"
else
  echo "FAILED: Expected: '$EXPECTED', and instead, got '$OUT'"
  exit 1
fi
